
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.019.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "Catmandu module for working with SRU data",
  "dist_author" => [
    "Wouter Willaert, C<< <wouterw\@inuits.eu> >>"
  ],
  "dist_name" => "Catmandu-SRU",
  "dist_version" => "0.035",
  "license" => "perl",
  "module_name" => "Catmandu::SRU",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Catmandu" => "0.9204",
    "Furl" => "0.41",
    "Moo" => "1.005000",
    "URI::Escape" => "1.60",
    "XML::LibXML::Simple" => "0.91",
    "XML::Struct" => "0.16",
    "YAML::XS" => "0.34",
    "perl" => "v5.10.1"
  },
  "script_files" => [],
  "test_requires" => {
    "Test::More" => "1.001003",
    "Test::Simple" => "1.001003",
    "XML::XPath" => "1.13"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.3601",
  "Test::More" => "1.001003",
  "Test::Simple" => "1.001003",
  "XML::XPath" => "1.13"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
